@@ -18,11 +18,11 @@ Passwd::Keyring::OSXKeychain - Password storage implementation based on OSX/Keyc
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 WARNING
 
@@ -109,7 +109,8 @@ sub new {
     # Some test operation
     my $reply = capturex($self->_make_sys_args(
         "-q",
-        "show-keychain-info"));
+        "show-keychain-info",
+        "default-keychain"));
 
     return $self;
 }
@@ -141,8 +142,8 @@ sub set_password {
         "-D", $self->{group}, # "kind", can be used to match so let be
         "-w", $user_password,
         "-j", $self->{app}, # comment
-        "-A", # any app can access
-        "-U", # allow update
+        # "-A", # any app can access  (note: alternative is -T app_path, which may be used many times). See issue #3
+        "-U", # update if present
         ));
 }
 
